.. multivitamin documentation master file, created by
   sphinx-quickstart on Mon Nov  4 13:15:28 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Multivitamin
========================================
Python supplements for serving CV, NLP, and ML models

Getting Started
===============

**Multivitamin** is python framework built for serving computer vision (CV), natural language processing (NLP), and machine learning (ML) models. It's aim is to provide the serving infrastructure around a single service and to allow the flexibility to use any python framework for prediction.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   multivitamin


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
